@@ -1,6 +1,6 @@
 from colorama import Fore, Style
 import sys
-from models import Durations
+from sylo.models import Durations
 
 
 def print_welcome():
